@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_GPIO_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_GPIO_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 
 LTTNG_TRACEPOINT_EVENT(gpio_direction,
 
@@ -35,4 +35,4 @@ LTTNG_TRACEPOINT_EVENT(gpio_value,
 #endif /* if !defined(LTTNG_TRACE_GPIO_H) || defined(TRACE_HEADER_MULTI_READ) */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
