@@ -84,6 +84,28 @@ LTTNG_TRACEPOINT_EVENT(kvm_ack_irq,
 	{ KVM_TRACE_MMIO_READ, "read" }, \
 	{ KVM_TRACE_MMIO_WRITE, "write" }
 
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,15,0) \
+	|| LTTNG_KERNEL_RANGE(4,14,14, 4,15,0) \
+	|| LTTNG_KERNEL_RANGE(4,9,77, 4,10,0) \
+	|| LTTNG_KERNEL_RANGE(4,4,112, 4,5,0) \
+	|| LTTNG_KERNEL_RANGE(3,16,52, 3,17,0) \
+	|| LTTNG_KERNEL_RANGE(3,2,97, 3,3,0) \
+	|| LTTNG_DEBIAN_KERNEL_RANGE(4,9,65,0,3,0, 4,10,0,0,0,0))
+
+LTTNG_TRACEPOINT_EVENT(kvm_mmio,
+	TP_PROTO(int type, int len, u64 gpa, void *val),
+	TP_ARGS(type, len, gpa, val),
+
+	TP_FIELDS(
+		ctf_integer(u32, type, type)
+		ctf_integer(u32, len, len)
+		ctf_integer(u64, gpa, gpa)
+		ctf_sequence_hex(unsigned char, val, val, u32, len)
+	)
+)
+
+#else
+
 LTTNG_TRACEPOINT_EVENT(kvm_mmio,
 	TP_PROTO(int type, int len, u64 gpa, u64 val),
 	TP_ARGS(type, len, gpa, val),
@@ -96,6 +118,8 @@ LTTNG_TRACEPOINT_EVENT(kvm_mmio,
 	)
 )
 
+#endif
+
 #if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,34))
 
 #define kvm_fpu_load_symbol	\
