@@ -4,7 +4,7 @@
 #if !defined(LTTNG_TRACE_SKB_H) || defined(TRACE_HEADER_MULTI_READ)
 #define LTTNG_TRACE_SKB_H
 
-#include "../../../probes/lttng-tracepoint-event.h"
+#include <probes/lttng-tracepoint-event.h>
 #include <linux/skbuff.h>
 #include <linux/netdevice.h>
 #include <linux/version.h>
@@ -59,4 +59,4 @@ LTTNG_TRACEPOINT_EVENT(skb_copy_datagram_iovec,
 #endif /* LTTNG_TRACE_SKB_H */
 
 /* This part must be outside protection */
-#include "../../../probes/define_trace.h"
+#include <probes/define_trace.h>
