@@ -2,6 +2,10 @@
 #include "x86-32-syscalls-3.1.0-rc6_pointers.h"
 #endif
 
+#ifdef CONFIG_ARM64
+#include "arm-32-syscalls-3.4.25_pointers.h"
+#endif
+
 #ifdef CONFIG_PPC64
 #include "powerpc-32-syscalls-3.0.34_pointers.h"
 #endif
