@@ -1,12 +1,14 @@
-#define OVERRIDE_32_mmap
-#define OVERRIDE_64_mmap
-
 #ifndef CREATE_SYSCALL_TABLE
 
+#define OVERRIDE_32_mmap
+#define OVERRIDE_64_mmap
 SC_LTTNG_TRACEPOINT_EVENT(mmap,
-	TP_PROTO(sc_exit(long ret,) unsigned long addr, unsigned long len, unsigned long prot, unsigned long flags, unsigned long fd, unsigned long off),
+	TP_PROTO(sc_exit(unsigned long ret,)
+		unsigned long addr, unsigned long len,
+		unsigned long prot, unsigned long flags,
+		unsigned long fd, unsigned long off),
 	TP_ARGS(sc_exit(ret,) addr, len, prot, flags, fd, off),
-	TP_FIELDS(sc_exit(ctf_integer(long, ret, ret))
+	TP_FIELDS(sc_exit(ctf_integer_hex(unsigned long, ret, ret))
 		sc_in(ctf_integer_hex(unsigned long, addr, addr))
 		sc_in(ctf_integer(size_t, len, len))
 		sc_in(ctf_integer(int, prot, prot))
