@@ -46,11 +46,13 @@
 #include <wrapper/random.h>
 #include <wrapper/tracepoint.h>
 #include <wrapper/list.h>
+#include <wrapper/types.h>
 #include <lttng-kernel-version.h>
 #include <lttng-events.h>
 #include <lttng-tracer.h>
 #include <lttng-abi-old.h>
 #include <lttng-endian.h>
+#include <lttng-string-utils.h>
 #include <wrapper/vzalloc.h>
 #include <wrapper/ringbuffer/backend.h>
 #include <wrapper/ringbuffer/frontend.h>
@@ -130,7 +132,7 @@ struct lttng_session *lttng_session_create(void)
 	int i;
 
 	mutex_lock(&sessions_mutex);
-	session = kzalloc(sizeof(struct lttng_session), GFP_KERNEL);
+	session = lttng_kvzalloc(sizeof(struct lttng_session), GFP_KERNEL);
 	if (!session)
 		goto err;
 	INIT_LIST_HEAD(&session->chan);
@@ -161,7 +163,7 @@ struct lttng_session *lttng_session_create(void)
 err_free_cache:
 	kfree(metadata_cache);
 err_free_session:
-	kfree(session);
+	lttng_kvfree(session);
 err:
 	mutex_unlock(&sessions_mutex);
 	return NULL;
@@ -184,7 +186,7 @@ void lttng_session_destroy(struct lttng_session *session)
 	int ret;
 
 	mutex_lock(&sessions_mutex);
-	ACCESS_ONCE(session->active) = 0;
+	WRITE_ONCE(session->active, 0);
 	list_for_each_entry(chan, &session->chan, list) {
 		ret = lttng_syscalls_unregister(chan);
 		WARN_ON(ret);
@@ -210,7 +212,7 @@ void lttng_session_destroy(struct lttng_session *session)
 	kref_put(&session->metadata_cache->refcount, metadata_cache_destroy);
 	list_del(&session->list);
 	mutex_unlock(&sessions_mutex);
-	kfree(session);
+	lttng_kvfree(session);
 }
 
 int lttng_session_statedump(struct lttng_session *session)
@@ -259,16 +261,16 @@ int lttng_session_enable(struct lttng_session *session)
 			lib_ring_buffer_clear_quiescent_channel(chan->chan);
 	}
 
-	ACCESS_ONCE(session->active) = 1;
-	ACCESS_ONCE(session->been_active) = 1;
+	WRITE_ONCE(session->active, 1);
+	WRITE_ONCE(session->been_active, 1);
 	ret = _lttng_session_metadata_statedump(session);
 	if (ret) {
-		ACCESS_ONCE(session->active) = 0;
+		WRITE_ONCE(session->active, 0);
 		goto end;
 	}
 	ret = lttng_statedump_start(session);
 	if (ret)
-		ACCESS_ONCE(session->active) = 0;
+		WRITE_ONCE(session->active, 0);
 end:
 	mutex_unlock(&sessions_mutex);
 	return ret;
@@ -284,7 +286,7 @@ int lttng_session_disable(struct lttng_session *session)
 		ret = -EBUSY;
 		goto end;
 	}
-	ACCESS_ONCE(session->active) = 0;
+	WRITE_ONCE(session->active, 0);
 
 	/* Set transient enabler state to "disabled" */
 	session->tstate = 0;
@@ -359,7 +361,7 @@ int lttng_channel_enable(struct lttng_channel *channel)
 	channel->tstate = 1;
 	lttng_session_sync_enablers(channel->session);
 	/* Set atomically the state to "enabled" */
-	ACCESS_ONCE(channel->enabled) = 1;
+	WRITE_ONCE(channel->enabled, 1);
 end:
 	mutex_unlock(&sessions_mutex);
 	return ret;
@@ -379,7 +381,7 @@ int lttng_channel_disable(struct lttng_channel *channel)
 		goto end;
 	}
 	/* Set atomically the state to "disabled" */
-	ACCESS_ONCE(channel->enabled) = 0;
+	WRITE_ONCE(channel->enabled, 0);
 	/* Set transient enabler state to "enabled" */
 	channel->tstate = 0;
 	lttng_session_sync_enablers(channel->session);
@@ -409,7 +411,7 @@ int lttng_event_enable(struct lttng_event *event)
 	case LTTNG_KERNEL_KPROBE:
 	case LTTNG_KERNEL_FUNCTION:
 	case LTTNG_KERNEL_NOOP:
-		ACCESS_ONCE(event->enabled) = 1;
+		WRITE_ONCE(event->enabled, 1);
 		break;
 	case LTTNG_KERNEL_KRETPROBE:
 		ret = lttng_kretprobes_event_enable_state(event, 1);
@@ -444,7 +446,7 @@ int lttng_event_disable(struct lttng_event *event)
 	case LTTNG_KERNEL_KPROBE:
 	case LTTNG_KERNEL_FUNCTION:
 	case LTTNG_KERNEL_NOOP:
-		ACCESS_ONCE(event->enabled) = 0;
+		WRITE_ONCE(event->enabled, 0);
 		break;
 	case LTTNG_KERNEL_KRETPROBE:
 		ret = lttng_kretprobes_event_enable_state(event, 0);
@@ -1142,11 +1144,11 @@ fd_error:
  * Enabler management.
  */
 static
-int lttng_match_enabler_wildcard(const char *desc_name,
-		const char *name)
+int lttng_match_enabler_star_glob(const char *desc_name,
+		const char *pattern)
 {
-	/* Compare excluding final '*' */
-	if (strncmp(desc_name, name, strlen(name) - 1))
+	if (!strutils_star_glob_match(pattern, LTTNG_SIZE_MAX,
+			desc_name, LTTNG_SIZE_MAX))
 		return 0;
 	return 1;
 }
@@ -1191,8 +1193,8 @@ int lttng_desc_match_enabler(const struct lttng_event_desc *desc,
 		return -EINVAL;
 	}
 	switch (enabler->type) {
-	case LTTNG_ENABLER_WILDCARD:
-		return lttng_match_enabler_wildcard(desc_name, enabler_name);
+	case LTTNG_ENABLER_STAR_GLOB:
+		return lttng_match_enabler_star_glob(desc_name, enabler_name);
 	case LTTNG_ENABLER_NAME:
 		return lttng_match_enabler_name(desc_name, enabler_name);
 	default:
@@ -1515,7 +1517,7 @@ void lttng_session_sync_enablers(struct lttng_session *session)
 		 */
 		enabled = enabled && session->tstate && event->chan->tstate;
 
-		ACCESS_ONCE(event->enabled) = enabled;
+		WRITE_ONCE(event->enabled, enabled);
 		/*
 		 * Sync tracepoint registration with event enabled
 		 * state.
@@ -1641,7 +1643,7 @@ int lttng_metadata_printf(struct lttng_session *session,
 	va_list ap;
 	struct lttng_metadata_stream *stream;
 
-	WARN_ON_ONCE(!ACCESS_ONCE(session->active));
+	WARN_ON_ONCE(!READ_ONCE(session->active));
 
 	va_start(ap, fmt);
 	str = kvasprintf(GFP_KERNEL, fmt, ap);
@@ -2228,7 +2230,7 @@ int _lttng_event_metadata_statedump(struct lttng_session *session,
 {
 	int ret = 0;
 
-	if (event->metadata_dumped || !ACCESS_ONCE(session->active))
+	if (event->metadata_dumped || !READ_ONCE(session->active))
 		return 0;
 	if (chan->channel_type == METADATA_CHANNEL)
 		return 0;
@@ -2295,7 +2297,7 @@ int _lttng_channel_metadata_statedump(struct lttng_session *session,
 {
 	int ret = 0;
 
-	if (chan->metadata_dumped || !ACCESS_ONCE(session->active))
+	if (chan->metadata_dumped || !READ_ONCE(session->active))
 		return 0;
 
 	if (chan->channel_type == METADATA_CHANNEL)
@@ -2452,7 +2454,7 @@ int _lttng_session_metadata_statedump(struct lttng_session *session)
 	struct lttng_event *event;
 	int ret = 0;
 
-	if (!ACCESS_ONCE(session->active))
+	if (!READ_ONCE(session->active))
 		return 0;
 	if (session->metadata_dumped)
 		goto skip_session;
@@ -2807,6 +2809,12 @@ static int __init lttng_events_init(void)
 	ret = lttng_init_cpu_hotplug();
 	if (ret)
 		goto error_hotplug;
+	printk(KERN_NOTICE "LTTng: Loaded modules v%s.%s.%s%s (%s)\n",
+		__stringify(LTTNG_MODULES_MAJOR_VERSION),
+		__stringify(LTTNG_MODULES_MINOR_VERSION),
+		__stringify(LTTNG_MODULES_PATCHLEVEL_VERSION),
+		LTTNG_MODULES_EXTRAVERSION,
+		LTTNG_VERSION_NAME);
 	return 0;
 
 error_hotplug:
@@ -2819,6 +2827,12 @@ error_kmem:
 	lttng_tracepoint_exit();
 error_tp:
 	lttng_context_exit();
+	printk(KERN_NOTICE "LTTng: Failed to load modules v%s.%s.%s%s (%s)\n",
+		__stringify(LTTNG_MODULES_MAJOR_VERSION),
+		__stringify(LTTNG_MODULES_MINOR_VERSION),
+		__stringify(LTTNG_MODULES_PATCHLEVEL_VERSION),
+		LTTNG_MODULES_EXTRAVERSION,
+		LTTNG_VERSION_NAME);
 	return ret;
 }
 
@@ -2836,6 +2850,12 @@ static void __exit lttng_events_exit(void)
 	kmem_cache_destroy(event_cache);
 	lttng_tracepoint_exit();
 	lttng_context_exit();
+	printk(KERN_NOTICE "LTTng: Unloaded modules v%s.%s.%s%s (%s)\n",
+		__stringify(LTTNG_MODULES_MAJOR_VERSION),
+		__stringify(LTTNG_MODULES_MINOR_VERSION),
+		__stringify(LTTNG_MODULES_PATCHLEVEL_VERSION),
+		LTTNG_MODULES_EXTRAVERSION,
+		LTTNG_VERSION_NAME);
 }
 
 module_exit(lttng_events_exit);
