@@ -157,6 +157,7 @@ struct user_msghdr;
 
 /* Hijack probe callback for compat system call enter */
 #define TP_PROBE_CB(_template)		&syscall_entry_probe
+#define LTTNG_SC_COMPAT
 #define SC_LTTNG_TRACEPOINT_EVENT(_name, _proto, _args, _fields) \
 	LTTNG_TRACEPOINT_EVENT(compat_syscall_entry_##_name, PARAMS(_proto), PARAMS(_args), \
 		PARAMS(_fields))
@@ -188,6 +189,7 @@ struct user_msghdr;
 #undef TP_PROBE_CB
 #undef _TRACE_SYSCALLS_INTEGERS_H
 #undef _TRACE_SYSCALLS_POINTERS_H
+#undef LTTNG_SC_COMPAT
 
 #undef SC_ENTER
 
@@ -239,6 +241,7 @@ struct user_msghdr;
 
 /* Hijack probe callback for compat system call exit */
 #define TP_PROBE_CB(_template)		&syscall_exit_probe
+#define LTTNG_SC_COMPAT
 #define SC_LTTNG_TRACEPOINT_EVENT(_name, _proto, _args, _fields) \
 	LTTNG_TRACEPOINT_EVENT(compat_syscall_exit_##_name, PARAMS(_proto), PARAMS(_args), \
 		PARAMS(_fields))
@@ -270,6 +273,7 @@ struct user_msghdr;
 #undef TP_PROBE_CB
 #undef _TRACE_SYSCALLS_INTEGERS_H
 #undef _TRACE_SYSCALLS_POINTERS_H
+#undef LTTNG_SC_COMPAT
 
 #undef SC_EXIT
 
@@ -1255,7 +1259,7 @@ long lttng_channel_syscall_mask(struct lttng_channel *channel,
 	filter = channel->sc_filter;
 
 	for (bit = 0; bit < ARRAY_SIZE(sc_table); bit++) {
-		bool state;
+		char state;
 
 		if (channel->sc_table) {
 			if (filter)
@@ -1268,7 +1272,7 @@ long lttng_channel_syscall_mask(struct lttng_channel *channel,
 		bt_bitfield_write_be(tmp_mask, char, bit, 1, state);
 	}
 	for (; bit < sc_tables_len; bit++) {
-		bool state;
+		char state;
 
 		if (channel->compat_sc_table) {
 			if (filter)
