@@ -36,16 +36,17 @@
 
 #include <wrapper/trace-clock.h>
 #include <wrapper/compiler.h>
+#include <wrapper/vmalloc.h>
 #include <lttng-tracer-core.h>
 #include <lttng-events.h>
 
 #define LTTNG_MODULES_MAJOR_VERSION 2
-#define LTTNG_MODULES_MINOR_VERSION 9
-#define LTTNG_MODULES_PATCHLEVEL_VERSION 1
+#define LTTNG_MODULES_MINOR_VERSION 10
+#define LTTNG_MODULES_PATCHLEVEL_VERSION 5
 #define LTTNG_MODULES_EXTRAVERSION ""
 
-#define LTTNG_VERSION_NAME		"Joannès"
-#define LTTNG_VERSION_DESCRIPTION	"Berliner Weisse style beer from the Trèfle Noir microbrewery in Rouyn-Noranda. It is a tangy beer with a distinct pink dress and intense fruit flavor, thanks to the presence of fresh blackcurrant grown in Témiscamingue."
+#define LTTNG_VERSION_NAME		"KeKriek"
+#define LTTNG_VERSION_DESCRIPTION	"From Brasserie Dunham, a sour mashed golden wheat ale fermented with local sour cherries from Tougas orchards. Fresh sweet cherry notes with some tartness, lively carbonation with a dry finish."
 
 #ifndef CHAR_BIT
 #define CHAR_BIT 8
