@@ -1143,14 +1143,14 @@ static void __event_probe__##_name(void *__data, _proto)		      \
 									      \
 	if (!_TP_SESSION_CHECK(session, __session))			      \
 		return;							      \
-	if (unlikely(!ACCESS_ONCE(__session->active)))			      \
+	if (unlikely(!READ_ONCE(__session->active)))			      \
 		return;							      \
-	if (unlikely(!ACCESS_ONCE(__chan->enabled)))			      \
+	if (unlikely(!READ_ONCE(__chan->enabled)))			      \
 		return;							      \
-	if (unlikely(!ACCESS_ONCE(__event->enabled)))			      \
+	if (unlikely(!READ_ONCE(__event->enabled)))			      \
 		return;							      \
 	__lpf = lttng_rcu_dereference(__session->pid_tracker);		      \
-	if (__lpf && likely(!lttng_pid_tracker_lookup(__lpf, current->pid)))  \
+	if (__lpf && likely(!lttng_pid_tracker_lookup(__lpf, current->tgid))) \
 		return;							      \
 	__orig_dynamic_len_offset = this_cpu_ptr(&lttng_dynamic_len_stack)->offset; \
 	__dynamic_len_idx = __orig_dynamic_len_offset;			      \
@@ -1217,11 +1217,11 @@ static void __event_probe__##_name(void *__data)			      \
 									      \
 	if (!_TP_SESSION_CHECK(session, __session))			      \
 		return;							      \
-	if (unlikely(!ACCESS_ONCE(__session->active)))			      \
+	if (unlikely(!READ_ONCE(__session->active)))			      \
 		return;							      \
-	if (unlikely(!ACCESS_ONCE(__chan->enabled)))			      \
+	if (unlikely(!READ_ONCE(__chan->enabled)))			      \
 		return;							      \
-	if (unlikely(!ACCESS_ONCE(__event->enabled)))			      \
+	if (unlikely(!READ_ONCE(__event->enabled)))			      \
 		return;							      \
 	__lpf = lttng_rcu_dereference(__session->pid_tracker);		      \
 	if (__lpf && likely(!lttng_pid_tracker_lookup(__lpf, current->pid)))  \
